[![badge doc](https://img.shields.io/badge/docs-v12.0.0-orange.svg)](https://www.idiap.ch/software/bob/docs/bob/bob/v12.0.0/index.html)
[![badge pipeline](https://gitlab.idiap.ch/bob/bob/badges/v12.0.0/pipeline.svg)](https://gitlab.idiap.ch/bob/bob/commits/v12.0.0)
[![badge coverage](https://gitlab.idiap.ch/bob/bob/badges/v12.0.0/coverage.svg)](https://gitlab.idiap.ch/bob/bob/commits/v12.0.0)
[![badge gitlab](https://img.shields.io/badge/gitlab-project-0000c0.svg)](https://gitlab.idiap.ch/bob/bob)

# Bob

[Bob](https://www.idiap.ch/software/bob) is a free signal-processing and machine
learning toolbox originally developed by the Biometrics group at the
[Idiap Research Institute](https://www.idiap.ch), Switzerland.

The toolbox is written in [Python](https://www.python.org) and is designed to be
both efficient and reduce development time. It is composed of a reasonably large
number of [packages](https://www.idiap.ch/software/bob/packages) that implement
tools for image, audio & video processing, machine learning & pattern
recognition, and a lot more task specific packages.

**Please visit our** [website](https://www.idiap.ch/software/bob) **for more**
**information.**

## Installation

This package does nothing by itself. You should not need to install it, it will
be installed as dependency of the utility package you use like
[bob.bio.face](https://gitlab.idiap.ch/bob/bob.bio.face).

## For the maintainers

The bob packages are developed using
[idiap-devtools](https://gitlab.idiap.ch/software/idiap-devtools). Please refer
to their documentation for release procedures.
